==> REDCapR_1.2.0.tar.gz: REDCapR/inst/test-data/specific-redcapr/project-info-read/all-test-projects.R <==
structure(list(project_id = c(153L, 212L, 213L, 268L, 690L, 691L, 
753L, 817L, 977L, 998L, 999L, 1396L, 1400L, 1425L, 1490L, 2545L, 
2545L, 2593L, 2597L, 2603L, 2626L, 2627L, 2629L, 2630L, 2631L, 
2632L, 2634L, 3003L, 3074L, 3181L), project_title = c("REDCapR Target Simple Static -see https://github.com/OuhscBbmc/REDCapR", 
"REDCapR Target Longitudinal Arm -see https://github.com/OuhscBbmc/REDCapR", 
"REDCapR Target Simple -Write Data", "REDCapR Russian -see https://github.com/OuhscBbmc/REDCapR", 
"REDCapR Target Empty Rows -see https://github.com/OuhscBbmc/REDCapR", 
"REDCapR Target Empty Columns -see https://github.com/OuhscBbmc/REDCapR", 
"REDCapR Target Super-wide -see https://github.com/OuhscBbmc/REDCapR", 
"REDCapR Target Survey Static -see https://github.com/OuhscBbmc/REDCapR", 
"REDCap Target Fake Clinical Trial", "REDCapR Target -nonumeric record_id", 
"REDCapR Target DAG -see https://github.com/OuhscBbmc/REDCapR", 
"REDCapR Problematic values", "REDCapR Repeating Instruments --See https://github.com/OuhscBbmc/REDCapR", 
"REDCapR Problematic dictionary", "REDCapR Target Simple -Write Metadata", 
"REDCapR Target DAG -Write Data -see https://github.com/OuhscBbmc/REDCapR", 
"REDCapR Target DAG -Write Data -see https://github.com/OuhscBbmc/REDCapR", 
"REDCapR Target Super-wide 2 -see https://github.com/OuhscBbmc/REDCapR", 
"REDCapR superwide 3", "REDCapR Repeating Instruments Sparse", 
"REDCapR Delete Single Arm", "REDCapR Delete Multiple Arms", 
"REDCapR Longitudinal Single Arm", "REDCapR Decimal Commas and Dots", 
"REDCapR Decimal Comma", "REDCapR Decimal Dots", "REDCapR Validation Types", 
"REDCapR Target Simple with Gray Form Status --see https://github.com/OuhscBbmc/REDCapR", 
"REDCapR Checkboxes 1", "REDCapR Vignette: Reading Repeating Measures"
), creation_time = structure(c(1385762300, 1409508475, 1409510046, 
1424542707, 1503371677, 1503372285, 1512140287, 1520372784, 1535128221, 
1536708074, 1536717011, 1570739027, 1571112561, 1573579416, 1579464868, 
1632500924, 1632500924, 1635560455, 1635866052, 1636077368, 1637557792, 
1637557976, 1637874534, 1637941852, 1637959298, 1637959358, 1638248591, 
1660433618, 1662155863, 1665019453), tzone = "America/Chicago", class = c("POSIXct", 
"POSIXt")), production_time = structure(c(NA_real_, NA_real_, 
NA_real_, NA_real_, NA_real_, NA_real_, NA_real_, NA_real_, NA_real_, 
NA_real_, NA_real_, NA_real_, NA_real_, NA_real_, NA_real_, NA_real_, 
NA_real_, NA_real_, NA_real_, NA_real_, NA_real_, NA_real_, NA_real_, 
NA_real_, NA_real_, NA_real_, NA_real_, NA_real_, NA_real_, NA_real_
), tzone = "America/Chicago", class = c("POSIXct", "POSIXt")), 
    in_production = c(FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, 
    FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, 
    FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, 
    FALSE, FALSE, FALSE, FALSE, FALSE, FALSE), project_language = c("English", 
    "English", "English", "English", "English", "English", "English", 
    "English", "English", "English", "English", "English", "English", 
    "English", "English", "English", "English", "English", "English", 
    "English", "English", "English", "English", "English", "English", 
    "English", "English", "English", "English", "English"), purpose = c(0L, 
    0L, 0L, 0L, 0L, 0L, 4L, 4L, 0L, 4L, 0L, 1L, 4L, 4L, 0L, 3L, 
    3L, 4L, 4L, 4L, 4L, 4L, 4L, 3L, 3L, 3L, 3L, 0L, 4L, 3L), 
    purpose_other = c(NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, 
    NA, "Testing REDCapR API library (in R)", NA, NA, NA, NA, 
    NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA), 
    project_notes = c(NA, NA, "see https://github.com/OuhscBbmc/REDCapR", 
    NA, NA, NA, NA, NA, "Generated & contributed by Peter Higgins at University of Michigan School of Medicine", 
    "Helps test functions when the record name is not numeric", 
    NA, "Contains values that might create problems for the API recipient", 
    "Repeating instruments", "Has variables or descriptions that might cause problems with the API", 
    "see https://github.com/OuhscBbmc/REDCapR", NA, NA, "Another very wide dataset.  Supports https://github.com/OuhscBbmc/REDCapR/issues/335", 
    "REDCapR  -- see https://github.com/OuhscBbmc/REDCapR/issues/335", 
    "Repeating instruments  See https://github.com/OuhscBbmc/REDCapR", 
    "REDCapR Test Suite: delete records from a single-arm project", 
    "REDCapR Test Suite: delete records from a multiple-arm project", 
    "Longitudinal project with only one arm", NA, NA, NA, "REDCapR using Validation Types", 
    "Created for \nhttps://github.com/OuhscBbmc/REDCapR/issues/386 & https://github.com/OuhscBbmc/REDCapR/pull/389", 
    "Variety of f checkboxes", "https://github.com/OuhscBbmc/REDCapR/blob/main/vignettes/longitudinal-and-repeating.Rmd"
    ), custom_record_label = c(NA, NA, NA, NA, NA, NA, NA, NA, 
    NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, 
    NA, NA, NA, NA, NA, NA, "[height]; [weight]; [bmi]"), secondary_unique_field = c(NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_), is_longitudinal = c(FALSE, TRUE, FALSE, FALSE, 
    FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, 
    FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, TRUE, 
    TRUE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE), has_repeating_instruments_or_events = c(FALSE, 
    FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, 
    FALSE, FALSE, TRUE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, 
    TRUE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, 
    FALSE, TRUE), surveys_enabled = c(FALSE, FALSE, FALSE, FALSE, 
    FALSE, FALSE, FALSE, TRUE, FALSE, FALSE, FALSE, FALSE, FALSE, 
    FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, TRUE, 
    FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE), 
    scheduling_enabled = c(FALSE, FALSE, FALSE, FALSE, FALSE, 
    FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, 
    FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, 
    FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE), record_autonumbering_enabled = c(TRUE, 
    FALSE, TRUE, FALSE, TRUE, TRUE, TRUE, TRUE, TRUE, FALSE, 
    FALSE, TRUE, TRUE, TRUE, TRUE, FALSE, FALSE, TRUE, TRUE, 
    TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, 
    TRUE), randomization_enabled = c(FALSE, FALSE, FALSE, FALSE, 
    FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, 
    FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, 
    FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE), 
    ddp_enabled = c(FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, 
    FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, 
    FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, 
    FALSE, FALSE, FALSE, FALSE, FALSE, FALSE), project_irb_number = c(NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_), project_grant_number = c(NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_
    ), project_pi_firstname = c(NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_
    ), project_pi_lastname = c(NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_
    ), display_today_now_button = c(TRUE, TRUE, TRUE, TRUE, TRUE, 
    TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, 
    TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, 
    TRUE, TRUE, TRUE, TRUE, TRUE), missing_data_codes = c(NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_), external_modules = c("cross_project_piping,form_status_tweaks,redcap_autofill,data_driven_project_banner", 
    "cross_project_piping,form_status_tweaks,redcap_autofill,data_driven_project_banner", 
    "cross_project_piping,form_status_tweaks,redcap_autofill,data_driven_project_banner", 
    "cross_project_piping,form_status_tweaks,redcap_autofill,data_driven_project_banner", 
    "cross_project_piping,form_status_tweaks,redcap_autofill,data_driven_project_banner", 
    "cross_project_piping,form_status_tweaks,redcap_autofill,data_driven_project_banner", 
    "cross_project_piping,form_status_tweaks,redcap_autofill,data_driven_project_banner", 
    "cross_project_piping,form_status_tweaks,redcap_autofill,data_driven_project_banner", 
    "cross_project_piping,form_status_tweaks,redcap_autofill,data_driven_project_banner", 
    "cross_project_piping,form_status_tweaks,redcap_autofill,data_driven_project_banner", 
    "cross_project_piping,form_status_tweaks,redcap_autofill,data_driven_project_banner", 
    "cross_project_piping,form_status_tweaks,redcap_autofill,data_driven_project_banner", 
    "cross_project_piping,form_status_tweaks,redcap_autofill,data_driven_project_banner", 
    "cross_project_piping,form_status_tweaks,redcap_autofill,data_driven_project_banner", 
    "cross_project_piping,form_status_tweaks,redcap_autofill,data_driven_project_banner", 
    "cross_project_piping,form_status_tweaks,redcap_autofill,data_driven_project_banner", 
    "cross_project_piping,form_status_tweaks,redcap_autofill,data_driven_project_banner", 
    "cross_project_piping,form_status_tweaks,redcap_autofill,data_driven_project_banner", 
    "cross_project_piping,form_status_tweaks,redcap_autofill,data_driven_project_banner", 
    "cross_project_piping,form_status_tweaks,redcap_autofill,data_driven_project_banner", 
    "cross_project_piping,form_status_tweaks,redcap_autofill,data_driven_project_banner", 
    "cross_project_piping,form_status_tweaks,redcap_autofill,data_driven_project_banner", 
    "cross_project_piping,form_status_tweaks,redcap_autofill,data_driven_project_banner", 
    "cross_project_piping,form_status_tweaks,redcap_autofill,data_driven_project_banner", 
    "cross_project_piping,form_status_tweaks,redcap_autofill,data_driven_project_banner", 
    "cross_project_piping,form_status_tweaks,redcap_autofill,data_driven_project_banner", 
    "cross_project_piping,form_status_tweaks,redcap_autofill,data_driven_project_banner", 
    "cross_project_piping,form_status_tweaks,redcap_autofill,data_driven_project_banner", 
    "cross_project_piping,form_status_tweaks,redcap_autofill,data_driven_project_banner", 
    "cross_project_piping,form_status_tweaks,redcap_autofill,data_driven_project_banner"
    ), bypass_branching_erase_field_prompt = c("0", "0", "0", 
    "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
    "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
    "0", "0", "0")), row.names = c(NA, -30L), class = c("tbl_df", 
"tbl", "data.frame"))

==> REDCapR_1.3.0.tar.gz: REDCapR/inst/test-data/specific-redcapr/project-info-read/all-test-projects.R <==
structure(list(project_id = c(33L, 34L, 36L, 37L, 38L, 39L, 40L, 
41L, 42L, 43L, 44L, 45L, 46L, 47L, 48L, 49L, 49L, 50L, 51L, 52L, 
53L, 54L, 55L, 56L, 57L, 58L, 59L, 60L, 61L, 62L), project_title = c("REDCapR: simple", 
"REDCapR: longitudinal", "REDCapR: simple-write", "REDCapR: russian", 
"REDCapR: empty rows", "REDCapR: single-column", "REDCapR: super-wide-1", 
"REDCapR: survey", "REDCapR: clinical-trial-1", "REDCapR: nonnumeric-record-id", 
"REDCapR: dag", "REDCapR: potentially-problematic-values", "REDCapR: repeating-instruments", 
"REDCapR: potentially-problematic-dictionary", "REDCapR: metadata-write", 
"REDCapR: dag-write", "REDCapR: dag-write", "REDCapR: super-wide-2", 
"REDCapR: super-wide-3", "REDCapR: repeating-instruments-sparse", 
"REDCapR: arm-single-delete", "REDCapR: arm-multiple-delete", 
"REDCapR: arm-single-longitudinal", "REDCapR: decimal-comma-and-dot", 
"REDCapR: comma", "REDCapR: decimal-dot", "REDCapR: valiation-types-1", 
"REDCapR: blank-for-gray-status", "REDCapR: checkboxes-1", "REDCapR: vignette-repeating"
), creation_time = structure(c(1728609678, 1728610817, 1728659834, 
1728662057, 1728662448, 1728678073, 1728681914, 1728682668, 1728684539, 
1728684968, 1728685335, 1728686037, 1728687457, 1728688739, 1728738760, 
1728743784, 1728743784, 1728744878, 1728761607, 1728765017, 1728766845, 
1728767641, 1728769237, 1728774178, 1728777080, 1728777990, 1728780635, 
1728784212, 1728793066, 1728828021), tzone = "America/Chicago", class = c("POSIXct", 
"POSIXt")), production_time = structure(c(NA_real_, NA_real_, 
NA_real_, NA_real_, NA_real_, NA_real_, NA_real_, NA_real_, NA_real_, 
NA_real_, NA_real_, NA_real_, NA_real_, NA_real_, NA_real_, NA_real_, 
NA_real_, NA_real_, NA_real_, NA_real_, NA_real_, NA_real_, NA_real_, 
NA_real_, NA_real_, NA_real_, NA_real_, NA_real_, NA_real_, NA_real_
), tzone = "America/Chicago", class = c("POSIXct", "POSIXt")), 
    in_production = c(FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, 
    FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, 
    FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, 
    FALSE, FALSE, FALSE, FALSE, FALSE, FALSE), project_language = c("English", 
    "English", "English", "English", "English", "English", "English", 
    "English", "English", "English", "English", "English", "English", 
    "English", "English", "English", "English", "English", "English", 
    "English", "English", "English", "English", "English", "English", 
    "English", "English", "English", "English", "English"), purpose = c(4L, 
    4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 
    4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L, 4L), 
    purpose_other = c(NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_), project_notes = c(NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_), custom_record_label = c(NA, NA, NA, NA, NA, 
    NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, 
    NA, NA, NA, NA, NA, NA, NA, NA, NA, "[height]; [weight]; [bmi]"
    ), secondary_unique_field = c(NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_
    ), is_longitudinal = c(FALSE, TRUE, FALSE, FALSE, FALSE, 
    FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, 
    FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, TRUE, TRUE, 
    FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE), has_repeating_instruments_or_events = c(FALSE, 
    FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, 
    FALSE, FALSE, TRUE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, 
    TRUE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, 
    FALSE, TRUE), surveys_enabled = c(FALSE, FALSE, FALSE, FALSE, 
    FALSE, FALSE, FALSE, TRUE, FALSE, FALSE, FALSE, FALSE, FALSE, 
    FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, TRUE, 
    FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE), 
    scheduling_enabled = c(FALSE, FALSE, FALSE, FALSE, FALSE, 
    FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, 
    FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, 
    FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE), record_autonumbering_enabled = c(TRUE, 
    FALSE, TRUE, FALSE, TRUE, TRUE, TRUE, TRUE, TRUE, FALSE, 
    FALSE, TRUE, TRUE, TRUE, TRUE, FALSE, FALSE, TRUE, TRUE, 
    TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, 
    TRUE), randomization_enabled = c(FALSE, FALSE, FALSE, FALSE, 
    FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, 
    FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, 
    FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE), 
    ddp_enabled = c(FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, 
    FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, 
    FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, 
    FALSE, FALSE, FALSE, FALSE, FALSE, FALSE), project_irb_number = c(NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_), project_grant_number = c(NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_
    ), project_pi_firstname = c(NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_
    ), project_pi_lastname = c(NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_
    ), display_today_now_button = c(TRUE, TRUE, TRUE, TRUE, TRUE, 
    TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, 
    TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, TRUE, 
    TRUE, TRUE, TRUE, TRUE, TRUE), missing_data_codes = c(NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_), external_modules = c("redcap_entity", "redcap_entity", 
    "redcap_entity", "redcap_entity", "redcap_entity", "redcap_entity", 
    "redcap_entity", "redcap_entity", "redcap_entity", "redcap_entity", 
    "redcap_entity", "redcap_entity", "redcap_entity", "redcap_entity", 
    "redcap_entity", "redcap_entity", "redcap_entity", "redcap_entity", 
    "redcap_entity", "redcap_entity", "redcap_entity", "redcap_entity", 
    "redcap_entity", "redcap_entity", "redcap_entity", "redcap_entity", 
    "redcap_entity", "redcap_entity", "redcap_entity", "redcap_entity"
    ), bypass_branching_erase_field_prompt = c("0", "0", "0", 
    "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
    "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", "0", 
    "0", "0", "0")), row.names = c(NA, -30L), class = c("tbl_df", 
"tbl", "data.frame"))
